API Reference
===============

Client
---------------
.. autoclass:: ldlm.Client
   :members:
   :undoc-members:

.. autoclass:: ldlm.Lock
   :members:
   :undoc-members:

Async Client
---------------
.. autoclass:: ldlm.AsyncClient
   :members:
   :undoc-members:

.. autoclass:: ldlm.AsyncLock
   :members:
   :undoc-members:

TLS Configuration
------------------
.. autoclass:: ldlm.TLSConfig
   :members:
   :undoc-members:

Exceptions
----------

.. automodule:: ldlm.exceptions
   :members:
   :exclude-members: from_rpc_error
